# pycafee

**PyCafee** is a Python library developed to help scientists evaluate their experimental data. We use Python's main scientific libraries, such as Numpy, SciPy, matplotlib, Statsmodel, Pandas, among others, as a motor to power the experimental data analysis, adding features that helps researchers make better conclusions. So, get a cup of coffee |cup_coffee| (or tea, or chocolate, or chimarrão, or any other beverage that makes you feel comfy) and let's understand your data!



**This project is under active development.**
